knxpy
-----

Installation
============

Prequisites
^^^^^^^^^^^
For the asyncio ip tunnel at least python 3.5 is required.
The thread ip tunnel should work with earlier python versions.
A simple python connector to knxd is also available.

Setup
^^^^^
run ``pip3 install knxpy``

or

* download the latest `release <http://github.com/BrechtBa/knxpy/releases>`_
* unzip and cd to the folder
* run ``python3 setup.py install``

Examples
========
To get started, check the `examples <http://github.com/BrechtBa/knxpy/tree/master/examples/>`_ folder
